<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>BoolEdit</name>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Bool</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">название</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Значение:</translation>
    </message>
    <message>
        <source>True</source>
        <translation type="obsolete">True</translation>
    </message>
    <message>
        <source>False</source>
        <translation type="obsolete">False</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Активный</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Название:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Отмена</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
</context>
<context>
    <name>DoubleEdit</name>
    <message>
        <source>Double</source>
        <translation type="obsolete">Двойной</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Значение:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">название</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Активный</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Название:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Отмена</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
</context>
<context>
    <name>IntEdit</name>
    <message>
        <source>Int</source>
        <translation type="obsolete">Int</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Значение:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">название</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Активный</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Название:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Отмена</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
</context>
<context>
    <name>LanguageOptions</name>
    <message>
        <location filename="languageoptions.cpp" line="74"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
</context>
<context>
    <name>ListEdit</name>
    <message>
        <source>String</source>
        <translation type="obsolete">Строка</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Внутр</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Двойной</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Bool</translation>
    </message>
    <message>
        <source>List</source>
        <translation type="obsolete">Список</translation>
    </message>
    <message>
        <source>Unknown Type</source>
        <translation type="obsolete">Неизвесный Тип</translation>
    </message>
    <message>
        <source>I do not understand the type %1.</source>
        <translation type="obsolete">Неизвестен тип %1.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Предупреждение</translation>
    </message>
    <message>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="obsolete">Неизвестно как изменить тип QVariant %1.</translation>
    </message>
    <message>
        <source>The item you selected is not a QListBoxVariant item. I do not know what to do.</source>
        <translation type="obsolete">Запись которую Вы выбрали не есть QListBoxVariant. Неизвестно что делать.</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Активный</translation>
    </message>
    <message>
        <source>Values:</source>
        <translation type="obsolete">Значения:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Название:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">название</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Отмена</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="obsolete">&amp;Создать</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="obsolete">Alt+N</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="obsolete">В&amp;верх</translation>
    </message>
    <message>
        <source>Alt+U</source>
        <translation type="obsolete">Alt+U</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="obsolete">&amp;Изменить</translation>
    </message>
    <message>
        <source>Alt+E</source>
        <translation type="obsolete">Alt+E</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="obsolete">В&amp;низ</translation>
    </message>
    <message>
        <source>Alt+D</source>
        <translation type="obsolete">Alt+D</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Удалить</translation>
    </message>
</context>
<context>
    <name>NewVariant</name>
    <message>
        <source>New Variant</source>
        <translation type="obsolete">Новый Вариант</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Тип:</translation>
    </message>
    <message>
        <source>String</source>
        <translation type="obsolete">Строка</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Внутр</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Двойной</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Bool</translation>
    </message>
    <message>
        <source>List</source>
        <translation type="obsolete">Список</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Название:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Отмена</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
</context>
<context>
    <name>ParamListEdit</name>
    <message>
        <location filename="paramlistedit.ui" line="30"/>
        <source>List</source>
        <translation>Список</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="41"/>
        <source>List:</source>
        <translation>Список:</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="64"/>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="paramlistedit.ui" line="71"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>ParameterEdit</name>
    <message>
        <location filename="parameteredit.ui" line="38"/>
        <source>Active</source>
        <translation>Активный</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="43"/>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="48"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="53"/>
        <source>Value</source>
        <translation>Значение</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="187"/>
        <source>Name already exists</source>
        <translation>Название уже существует</translation>
    </message>
    <message>
        <source>The name for the parameter you specified already exists in the list.</source>
        <translation type="obsolete">Название указанное Вами для параметра уже существует в списке.</translation>
    </message>
    <message>
        <source>String</source>
        <translation type="obsolete">Строка</translation>
    </message>
    <message>
        <source>Int</source>
        <translation type="obsolete">Внутр</translation>
    </message>
    <message>
        <source>Double</source>
        <translation type="obsolete">Двойной</translation>
    </message>
    <message>
        <source>Bool</source>
        <translation type="obsolete">Bool</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="113"/>
        <source>List</source>
        <translation>Список</translation>
    </message>
    <message>
        <source>Unknown Type</source>
        <translation type="obsolete">Неизвесный Тип</translation>
    </message>
    <message>
        <source>I do not understand the type %1.</source>
        <translation type="obsolete">Не понятен тип %1.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Предупреждение</translation>
    </message>
    <message>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="obsolete">Невозможно изменить тип QVariant %1.</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="31"/>
        <source>Parameter List</source>
        <translation>Список Параметров</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="63"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="66"/>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="73"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="76"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="93"/>
        <source>&amp;New</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="96"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="103"/>
        <source>&amp;Edit</source>
        <translation>&amp;Изменить</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="106"/>
        <location filename="parameteredit.ui" line="116"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="parameteredit.ui" line="123"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="75"/>
        <source>Not a Valid Report</source>
        <translation>Не Верный Отчет</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="76"/>
        <source>The report definition does not appear to be a valid report.

The root node is not &apos;report&apos;.</source>
        <translation>Определение отчета скорее всего неверно.

Родительская ветка не есть &apos;отчетом&apos;.</translation>
    </message>
    <message>
        <location filename="parameteredit.cpp" line="188"/>
        <source>&lt;p&gt;The name for the parameter you specified already exists in the list.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ParameterProperties</name>
    <message>
        <location filename="parameterproperties.ui" line="14"/>
        <source>Parameter Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="20"/>
        <source>Type:</source>
        <translation type="unfinished">Тип:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="34"/>
        <location filename="parameterproperties.cpp" line="107"/>
        <location filename="parameterproperties.cpp" line="207"/>
        <location filename="parameterproperties.cpp" line="274"/>
        <location filename="parameterproperties.cpp" line="301"/>
        <source>String</source>
        <translation type="unfinished">Строка</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="39"/>
        <location filename="parameterproperties.cpp" line="95"/>
        <location filename="parameterproperties.cpp" line="198"/>
        <location filename="parameterproperties.cpp" line="280"/>
        <location filename="parameterproperties.cpp" line="307"/>
        <source>Bool</source>
        <translation type="unfinished">Bool</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="44"/>
        <location filename="parameterproperties.cpp" line="99"/>
        <location filename="parameterproperties.cpp" line="201"/>
        <location filename="parameterproperties.cpp" line="276"/>
        <location filename="parameterproperties.cpp" line="303"/>
        <source>Int</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="49"/>
        <location filename="parameterproperties.cpp" line="103"/>
        <location filename="parameterproperties.cpp" line="204"/>
        <location filename="parameterproperties.cpp" line="278"/>
        <location filename="parameterproperties.cpp" line="305"/>
        <source>Double</source>
        <translation type="unfinished">Двойной</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="54"/>
        <location filename="parameterproperties.cpp" line="111"/>
        <location filename="parameterproperties.cpp" line="210"/>
        <location filename="parameterproperties.cpp" line="282"/>
        <location filename="parameterproperties.cpp" line="309"/>
        <source>List</source>
        <translation type="unfinished">Список</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="72"/>
        <source>Name:</source>
        <translation type="unfinished">Название:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="95"/>
        <location filename="parameterproperties.ui" line="115"/>
        <location filename="parameterproperties.ui" line="155"/>
        <location filename="parameterproperties.ui" line="175"/>
        <source>Value:</source>
        <translation type="unfinished">Значение:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="135"/>
        <source>False</source>
        <translation type="unfinished">False</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="140"/>
        <source>True</source>
        <translation type="unfinished">True</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="192"/>
        <source>Values:</source>
        <translation type="unfinished">Значения:</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="210"/>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Создать</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="213"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="230"/>
        <source>Move &amp;Up</source>
        <translation type="unfinished">В&amp;верх</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="233"/>
        <source>Alt+U</source>
        <translation type="unfinished">Alt+U</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="240"/>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Изменить</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="243"/>
        <source>Alt+E</source>
        <translation type="unfinished">Alt+E</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="250"/>
        <source>Move &amp;Down</source>
        <translation type="unfinished">В&amp;низ</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="253"/>
        <source>Alt+D</source>
        <translation type="unfinished">Alt+D</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="270"/>
        <source>Delete</source>
        <translation type="unfinished">Удалить</translation>
    </message>
    <message>
        <location filename="parameterproperties.ui" line="299"/>
        <source>Active</source>
        <translation type="unfinished">Активный</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="115"/>
        <location filename="parameterproperties.cpp" line="188"/>
        <location filename="parameterproperties.cpp" line="213"/>
        <source>Warning</source>
        <translation type="unfinished">Предупреждение</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="116"/>
        <source>I do not know how to edit QVariant type %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="189"/>
        <location filename="parameterproperties.cpp" line="214"/>
        <source>I do not recognize type %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="285"/>
        <location filename="parameterproperties.cpp" line="312"/>
        <source>Unknown Type</source>
        <translation type="unfinished">Неизвесный Тип</translation>
    </message>
    <message>
        <location filename="parameterproperties.cpp" line="286"/>
        <location filename="parameterproperties.cpp" line="313"/>
        <source>I do not understand the type %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="data.cpp" line="25"/>
        <source>%1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="data.cpp" line="26"/>
        <source>Copyright (c) 2002-2012, OpenMFG, LLC.</source>
        <oldsource>Copyright (c) 2002-2011, OpenMFG, LLC.</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="data.cpp" line="28"/>
        <source>3.3.4</source>
        <oldsource>3.3.1</oldsource>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StringEdit</name>
    <message>
        <source>String</source>
        <translation type="obsolete">Строка</translation>
    </message>
    <message>
        <source>Value:</source>
        <translation type="obsolete">Значение:</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">название</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="obsolete">Активный</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Название:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation type="obsolete">Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Отмена</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation type="obsolete">Alt+C</translation>
    </message>
</context>
<context>
    <name>login</name>
    <message>
        <location filename="login.cpp" line="146"/>
        <source>Initializing the Database Connector</source>
        <translation>Инициализация Соединения с Базой Данных</translation>
    </message>
    <message>
        <location filename="login.cpp" line="159"/>
        <source>No Database Driver</source>
        <translation>Нет Драйвера Базы Данных</translation>
    </message>
    <message>
        <location filename="login.cpp" line="160"/>
        <source>A connection could not be established with the specified
Database as the Proper Database Drivers have not been installed.
Contact your Systems Administrator.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="login.cpp" line="180"/>
        <source>Connecting to the Database</source>
        <translation>Соединение с Базой Данных</translation>
    </message>
    <message>
        <location filename="login.cpp" line="193"/>
        <source>Cannot Connect to Database Server</source>
        <translation>Невозможно Соединится с Сервером Базы Данных</translation>
    </message>
    <message>
        <location filename="login.cpp" line="194"/>
        <source>A connection to the specified Database Server cannot be made.  This may be due to an
incorrect Username and/or Password or that the Database Server in question cannot
support anymore connections.

Please verify your Username and Password and try again or wait until the specified
Database Server is less busy.

System Error &apos;%1&apos;
%2</source>
        <translation type="unfinished">A connection to the specified Database Server cannot be made.  This may be due to an
incorrect Username and/or Password or that the Database Server in question cannot
support anymore connections.

Please verify your Username and Password and try again or wait until the specified
Database Server is less busy.

Системная Ошибка &apos;%1&apos;
%2</translation>
    </message>
    <message>
        <location filename="login.cpp" line="214"/>
        <source>Logging into the Database</source>
        <translation>Вход в Базу Данных</translation>
    </message>
    <message>
        <location filename="login.ui" line="31"/>
        <source>Log In</source>
        <translation>Вход</translation>
    </message>
    <message>
        <location filename="login.ui" line="2010"/>
        <source>Build: </source>
        <translation>Build: </translation>
    </message>
    <message>
        <location filename="login.ui" line="2538"/>
        <source>&amp;Username:</source>
        <translation>&amp;Пользователь:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2551"/>
        <source>&amp;Password:</source>
        <translation>&amp;Пароль:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2637"/>
        <source>S&amp;erver:</source>
        <translation>С&amp;ервер:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2650"/>
        <source>&amp;Database:</source>
        <translation>&amp;База Данных:</translation>
    </message>
    <message>
        <location filename="login.ui" line="2781"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <location filename="login.ui" line="2788"/>
        <source>&amp;Login</source>
        <translation>&amp;Логин</translation>
    </message>
    <message>
        <location filename="login.ui" line="2801"/>
        <source>&amp;Options</source>
        <translation>&amp;Опции</translation>
    </message>
    <message>
        <location filename="login.cpp" line="112"/>
        <source>Version </source>
        <translation>Версия</translation>
    </message>
</context>
<context>
    <name>loginOptions</name>
    <message>
        <location filename="loginOptions.ui" line="31"/>
        <source>Login Options</source>
        <translation>Опции Входа</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="87"/>
        <source>&amp;Database:</source>
        <translation>&amp;База Данных:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="194"/>
        <source>S&amp;erver:</source>
        <translation>С&amp;ервер:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="219"/>
        <source>&amp;Port:</source>
        <translation>&amp;Порт:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="246"/>
        <source>Driver:</source>
        <translation>Драйвер:</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="309"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="316"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="260"/>
        <source>PostgreSQL</source>
        <translation>PostgreSQL</translation>
    </message>
    <message>
        <location filename="loginOptions.ui" line="265"/>
        <source>ODBC</source>
        <translation>ODBC</translation>
    </message>
</context>
</TS>
